@@ -24,13 +24,15 @@ def surface_lattice_sum(x, y, z,
 
 
     for i in numba.prange(Nh):
+        pidi = -2.0*(pi*dinv[i])**2
+        hi, ki, li = h[i], k[i], l[i]
         for j in range(Noc):
             # Loop over symmetry operations
             tmp=0.0j
             for m in range(Pt.shape[0]):
                 tmp+=exp(2.0j*pi*(
-                        h[i]*(Pt[m, 0, 0]*x[j] + Pt[m, 0, 1]*y[j] + Pt[m, 0, 2])+
-                        k[i]*(Pt[m, 1, 0]*x[j] + Pt[m, 1, 1]*y[j]+ Pt[m, 1, 2]) +
-                        l[i]*z[j]))
-            fs[i]+=oc[j]*f[i, j]*exp(-2.0*pow(pi*dinv[i], 2.0)*u[j])*tmp
+                        hi*(Pt[m, 0, 0]*x[j] + Pt[m, 0, 1]*y[j] + Pt[m, 0, 2])+
+                        ki*(Pt[m, 1, 0]*x[j] + Pt[m, 1, 1]*y[j]+ Pt[m, 1, 2]) +
+                        li*z[j]))
+            fs[i]+=oc[j]*f[i, j]*exp(pidi*u[j])*tmp
     return fs
