@@ -136,7 +136,7 @@ instrument_string_choices={'probe': ['x-ray', 'neutron', 'neutron pol',
                            'pol': ['uu', 'dd', 'ud', 'ass', 'du']}
 InstrumentParameters={'probe': 'x-ray', 'wavelength': 1.54, 'coords': 'tth',
                       'I0': 1.0, 'res': 0.001,
-                      'restype': 'no conv', 'respoints': 5, 'resintrange': 2, 'beamw': 0.01,
+                      'restype': 'no conv', 'respoints': 5, 'resintrange': 2.0, 'beamw': 0.01,
                       'footype': 'no corr', 'samplelen': 10.0, 'incangle': 0.0, 'pol': 'uu',
                       'Ibkg': 0.0, 'tthoff': 0.0}
 InstrumentGroups=[('General', ['wavelength', 'coords', 'I0', 'Ibkg', 'tthoff']),
@@ -189,6 +189,9 @@ AA_to_eV=12398.5
 q_limit=1e-10
 ''' Minimum allowed q-value '''
 
+__xlabel__ = "q [Å$^{-1}$]"
+__ylabel__ = "Instnsity [a.u.]"
+
 # A buffer to save previous calculations for spin-flip calculations
 class Buffer:
     Ruu=0
@@ -239,6 +242,9 @@ def resolutioncorr(R, TwoThetaQz, foocor, instrument, weight):
 
 def resolution_init(TwoThetaQz, instrument):
     ''' Inits the dependet variable with regards to coordinates and resolution.'''
+    global __xlabel__
+    __xlabel__ = "q [Å$^{-1}$]"
+
     restype=instrument.getRestype()
     weight=0
     if restype==2 or restype==instrument_string_choices['restype'][2]:
@@ -253,6 +259,7 @@ def resolution_init(TwoThetaQz, instrument):
     if instrument.getCoords()==instrument_string_choices['coords'][1] \
             or instrument.getCoords()==1:
         Q=4*pi/instrument.getWavelength()*sin((TwoThetaQz+instrument.getTthoff())*pi/360.0)
+        __xlabel__ = "2θ [°]"
     # Q vector given....
     elif instrument.getCoords()==instrument_string_choices['coords'][0] \
             or instrument.getCoords()==0:
@@ -492,17 +499,21 @@ def SLD_calculations(z, item, sample, inst):
                                           0.5*erf((z[:, newaxis]-int_pos)/sqrt(2.)/sigma)), 1)+sld_p[-1]
         rho_m=sum((sld_m[:-1]-sld_m[1:])*(0.5-
                                           0.5*erf((z[:, newaxis]-int_pos)/sqrt(2.)/sigma)), 1)+sld_m[-1]
-        rho_mag_x=sum((mag_sld_x[:-1]-mag_sld_x[1:])*
-                      (0.5-0.5*erf((z[:, newaxis]-int_pos)/sqrt(2.)/sigma)), 1)+mag_sld_x[-1]
-        rho_mag_y=sum((mag_sld_y[:-1]-mag_sld_y[1:])*
-                      (0.5-0.5*erf((z[:, newaxis]-int_pos)/sqrt(2.)/sigma)), 1)+mag_sld_y[-1]
-        # dic = {'Re sld +': real(rho_p), 'Im sld +': imag(rho_p),\
-        #        'Re sld -': real(rho_m), 'Im sld -': imag(rho_m), 'z':z,
-        #        'SLD unit': sld_unit}
-        rho_nucl=(rho_p+rho_m)/2.
-        dic={'Re non-mag': real(rho_nucl), 'Im non-mag': imag(rho_nucl),
-             'mag': real(rho_p-rho_m)/2, 'mag_x': rho_mag_x, 'mag_y': rho_mag_y,
-             'z': z, 'SLD unit': sld_unit}
+        rho_nucl = (rho_p+rho_m)/2.
+        if (magn_ang!=0.).any():
+            rho_mag_x=sum((mag_sld_x[:-1]-mag_sld_x[1:])*
+                          (0.5-0.5*erf((z[:, newaxis]-int_pos)/sqrt(2.)/sigma)), 1)+mag_sld_x[-1]
+            rho_mag_y=sum((mag_sld_y[:-1]-mag_sld_y[1:])*
+                          (0.5-0.5*erf((z[:, newaxis]-int_pos)/sqrt(2.)/sigma)), 1)+mag_sld_y[-1]
+            dic={'Re non-mag': real(rho_nucl), 'Im non-mag': imag(rho_nucl),
+                 'mag': real(rho_p-rho_m)/2, 'z': z, 'mag_x': rho_mag_x, 'mag_y': rho_mag_y,
+                 'SLD unit': sld_unit}
+        else:
+            dic = {
+                'Re non-mag': real(rho_nucl), 'Im non-mag': imag(rho_nucl),
+                'mag': real(rho_p-rho_m)/2, 'z': z,
+                'SLD unit': sld_unit
+                }
     if item is None or item=='all':
         return dic
     else:
