@@ -123,6 +123,9 @@ else:
 
 __pars__=['Sample', 'UnitCell', 'Slab', 'AtomGroup', 'Instrument', 'Domain']
 
+__xlabel__ = "q-scan [r.l.u.]"
+__ylabel__ = "Instnsity [a.u.]"
+
 class SimMethodInfo:
     def __init__(self, name, args, def_args):
         """Container to hold the info about simulation methods
@@ -727,8 +730,8 @@ class Slab:
         self.u=np.array([], dtype=np.float64)
         self.oc=np.array([], dtype=np.float64)
         self.m=np.array([], dtype=np.float64)
-        self.id=np.array([], dtype=np.str)
-        self.el=np.array([], dtype=np.str)
+        self.id=np.array([], dtype=str)
+        self.el=np.array([], dtype=str)
 
         # TODO: Type checking and defaults!
         # self.inst = inst
