@@ -6,6 +6,7 @@ This plugin auto generates the sample definition and simulations of a surface x-
 import os
 import io
 import traceback
+from logging import debug
 
 import wx
 
@@ -13,6 +14,7 @@ from .. import add_on_framework as framework
 from .help_modules import model_interactors as mi
 from .help_modules import atom_viewer
 from genx.core.custom_logging import iprint
+from genx.core.decorators import log_call
 from genx.gui.solvergui import EVT_UPDATE_SCRIPT
 
 code="""
@@ -59,7 +61,6 @@ code="""
 
 class Plugin(framework.Template):
     def __init__(self, parent):
-        # print "__init__ SXRD Plugin"
 
         framework.Template.__init__(self, parent)
         self.setup_script_interactor()
@@ -88,6 +89,7 @@ class Plugin(framework.Template):
         parent.model_control.Bind(EVT_UPDATE_SCRIPT, self.ReadUpdateModel)
 
 
+    @log_call
     def ReadUpdateModel(self, evt):
         self.script_interactor.parse_code(self.GetModelScript())
         self.OnInteractorChanged(None)
@@ -113,6 +115,7 @@ class Plugin(framework.Template):
 
         self.script_interactor=script_interactor
 
+    @log_call
     def layout_sample_view(self):
         """Layouts the sample_view_panel"""
         panel=self.NewPlotFolder('Test')
@@ -125,6 +128,7 @@ class Plugin(framework.Template):
         sizer.Add(self.sample_edit_widget, 1, wx.EXPAND)
         panel.Layout()
 
+    @log_call
     def layout_sample_edit(self):
         """Layouts the sample_edit_panel"""
         panel=self.NewInputFolder('Sample')
@@ -140,6 +144,7 @@ class Plugin(framework.Template):
         sizer.Add(self.sample_edit_widget, 1, wx.EXPAND)
         panel.Layout()
 
+    @log_call
     def layout_simulation_edit(self):
         """Layouts the simulation_edit_panel"""
         panel=self.NewInputFolder('Simulations')
@@ -150,6 +155,7 @@ class Plugin(framework.Template):
         sizer.Add(self.simulation_edit_widget, 1, wx.EXPAND)
         panel.Layout()
 
+    @log_call
     def layout_misc_edit(self):
         """Layouts the misc_edit_panel"""
         panel=self.NewDataFolder('Misc')
@@ -175,9 +181,9 @@ class Plugin(framework.Template):
         col_box_sizer.Add(self.instrument_edit_widget, 1, wx.EXPAND)
         panel.Layout()
 
+    @log_call
     def layout_domain_viewer(self):
         """Creates a 3D view of the sample."""
-        # print "layout_domain_viewer"
         panel=self.NewPlotFolder('Sample view')
         sample_view_sizer=wx.BoxSizer(wx.HORIZONTAL)
         panel.SetSizer(sample_view_sizer)
@@ -190,23 +196,20 @@ class Plugin(framework.Template):
         sample_view_sizer.Add(self.sample_view, 1, wx.EXPAND | wx.GROW | wx.ALL)
 
         toolbar.Realize()
-        toolbar.ReadConfig=lambda: None
-        panel.Layout()
 
         # Just to init the view properly
         cur_page=self.parent.plot_notebook.Selection
         self.parent.plot_notebook.SetSelection(self.parent.plot_notebook.GetPageCount()-1)
         self.parent.plot_notebook.SetSelection(cur_page)
         self.sample_view.show()
-        panel.Layout()
-        # print "end layout_domain_viewer"
 
+    @log_call
     def create_main_window_menu(self):
         """Creates the window menu"""
         self.menu=self.NewMenu('SXRD')
         menu_item=wx.MenuItem(self.menu, wx.NewId(), "Domain Viewer/Export Settings...", "Edit Viewer settings",
                               wx.ITEM_NORMAL)
-        self.menu.AppendItem(menu_item)
+        self.menu.Append(menu_item)
         mb_export_xyz=wx.MenuItem(self.menu, wx.NewId(),
                                        "Export XYZ...",
                                        "Export the SLD to a XYZ ASCII file",
@@ -238,7 +241,6 @@ class Plugin(framework.Template):
     def update_data_names(self):
         """Updates the DataSetInteractors names from the DataSet names in the model"""
         data_set_list=self.GetModel().data
-        # print "update_data_names"
 
         #assert (len(data_set_list)==len(self.script_interactor.data_sections_interactors))
 
@@ -282,7 +284,6 @@ class Plugin(framework.Template):
 
     def OnInteractorChanged(self, event):
         """Callback when an Interactor has been changed by the GUI"""
-        # print "OnInteractor Changed"
         self.update_script()
         self.set_constant_names()
         self.update_widgets()
@@ -290,19 +291,16 @@ class Plugin(framework.Template):
 
     def OnSelectionChanged(self, evnet):
         """Callback when the selection in the sample widget has changed"""
-        # print "OnSelectionChanged"
         self.update_domain_view()
 
     def OnNewModel(self, event):
         """Callback for creating a new model"""
-        # print "OnNewModel"
         self.update_script()
         self.update_data_names()
         self.simulation_edit_widget.Update()
 
     def OnOpenModel(self, event):
         """Callback for opening a model"""
-        # print 'OnOpenModel'
         self.script_interactor.parse_code(self.GetModelScript())
         self.update_data_names()
         self.simulation_edit_widget.Update()
@@ -312,7 +310,6 @@ class Plugin(framework.Template):
         """Callback for changing of the data sets (dataset added or removed)"""
         # We have the following possible events:
         # event.new_model, event.data_moved, event.deleted, event.new_data, event.name_change
-        # print "OnDataChanged"
         if event.new_model:
             # If a new model is created bail out
             return
