@@ -24,10 +24,11 @@ from abc import ABC, abstractmethod
 
 from wx.lib.mixins.listctrl import ListCtrlAutoWidthMixin
 from math import cos, pi, sqrt
+from orsopy.slddb import api
+
 from ...gui import images as img
 from .. import add_on_framework as framework
 from .help_modules.materials_db import mdb, MaterialsDatabase, Formula, MASS_DENSITY_CONVERSION
-from .help_modules.slddb import api
 from ..utils import ShowInfoDialog, ShowQuestionDialog
 from ...gui.custom_choice_dialog import SCDialog
 
@@ -599,7 +600,7 @@ class MaterialDialog(wx.Dialog):
                 items.append(f'{i+1}: {name} ({sgs}) |'
                              f' Density: {dens:.3g} g/cm³ |'
                              f' UC Volume: {V}\n{text}')
-            dia=wx.SCDialog(self,
+            dia=SCDialog(self,
                           'Several entries have been found, please select appropriate:',
                           'Select correct database entry', items)
             if not dia.ShowModal()==wx.ID_OK:
