@@ -8,6 +8,7 @@ import re
 import json
 
 from genx.models.utils import bc, fp, fw, __bc_dict__  # @UnusedImport
+from genx.models.lib.physical_constants import MASS_DENSITY_CONVERSION
 from genx.core.custom_logging import iprint
 
 # configuration file to store the known materials
@@ -36,7 +37,6 @@ default_materials=[
     [[["Ti", 1.0], ["O", 2.0]], "4.0/(4.5318*5.5019*4.9063)"],
     ]
 
-MASS_DENSITY_CONVERSION=0.60221415  # g/cm³-> u/Å³ : 1e-24 (1/cm³->1/Å³) * 6.0221415e23 (Na)
 
 class Formula(list):
     '''
@@ -51,7 +51,7 @@ class Formula(list):
             if len(di)!=2:
                 raise ValueError('Formula has to consist of [Element, fraction] entries')
             if not self.check_atom(di[0]):
-                raise ValueError('Element/Isotope %s no in database'%di[0])
+                raise ValueError('Element/Isotope %s not in database'%di[0])
             di[1]=float(di[1])
         list.__init__(self, data)
 
@@ -117,7 +117,7 @@ class Formula(list):
         items=map(str.strip, bstr.split('+'))
         extracted_elements=[]
         for item in items:
-            if not item.startswith('bc.'):
+            if not item[:3] in ['bc.', 'bw.']:
                 continue
             else:
                 element, count=item[3:].split('*', 1)
@@ -267,6 +267,19 @@ class Formula(list):
             elements+='+fp.%s*%g'%(element, count)
         return elements[1:]
 
+    def fw(self):
+        '''Return string to be used in models to calculate scattering power f'''
+        if len(self)==0:
+            return '0.j'
+        fw.set_wavelength(1.54)
+        elements=''
+        total=sum(self.amounts())
+        for element, count in self:
+            if element in isotopes:
+                element=isotopes[element][1]
+            elements+='+fw.%s*%g'%(element, count/total)
+        return elements[1:]
+
     def b(self):
         '''Return string to be used in models to calculate scattering length b'''
         if len(self)==0:
@@ -278,6 +291,18 @@ class Formula(list):
             elements+='+bc.%s*%g'%(element, count)
         return elements[1:]
 
+    def bw(self):
+        '''Return string to be used in models to calculate scattering length b'''
+        if len(self)==0:
+            return '0.j'
+        elements=''
+        total=sum(self.amounts())
+        for element, count in self:
+            if element in isotopes:
+                element=isotopes[element][0]
+            elements+='+bw.%s*%g'%(element, count/total)
+        return elements[1:]
+
 class MaterialsDatabase(list):
     '''
     Holds a list of materials and associated methods.
