@@ -51,8 +51,8 @@ class Plugin(Template):
         Loads the data from filename into the data_item_number.
         '''
         try:
-            load_array=np.loadtxt(filename, delimiter=self.delimiter,
-                                  comments=self.comment, skiprows=self.skip_rows)
+            with open(filename, encoding='utf-8', errors='ignore') as fh:
+                load_array=np.loadtxt(fh, delimiter=self.delimiter, comments=self.comment, skiprows=self.skip_rows)
         except Exception as e:
             ShowWarningDialog(self.parent, 'Could not load the file: '+ \
                               filename+' \nPlease check the format.\n\n numpy.loadtxt' \
